import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:wowit/common.dart';
import 'package:wowit/methods.dart';

class SQLService {
  static Future<Map<String, List<Map<String, Object>>>> execute(String query,
      {Map<String, Object> params}) async {
    var queryParameters = {
      'query': query,
    };
    if (params == null) {
      params = {};
    }
    if (!params.containsKey('uid') && !params.containsKey('@uid')) {
      params['uid'] = Common.uid;
    }
    if (!params.containsKey('languageId') &&
        !params.containsKey('@languageId')) {
      params['languageId'] = Common.languageId;
    }
    queryParameters['jParam'] = jsonEncode(params);
    Map<String, List<Map<String, Object>>> retVal = {};
    try {
      print('SQLService.execute: ' + jsonEncode(queryParameters));
      var response =
          await http.post(Methods.getURI('/data/exec'), body: queryParameters);
      if (response.statusCode == 200) {
        print('SQLService.execute with ' +
            query +
            ' reponse status code = ' +
            response.statusCode.toString());
        if (response.body == "") {
          print('response.body is empty');
          return retVal;
        }
        Map<String, dynamic> jsonData =
            json.decode(response.body); //--> return data set
        jsonData.forEach((key, value) {
          List<dynamic> table = value;
          List<Map<String, Object>> rsTable = [];
          for (int i = 0; i < table.length; i++) {
            rsTable.add(table[i]);
          }
          retVal[key] = rsTable;
        });
      }
    } catch (e) {
      print('SQLService.execute with exception:  ' + e.toString());
    }

    if(retVal.length > 0 &&retVal.containsKey('Exception') )
    {
      var dataException = Methods.getList(retVal, 'Exception');
      if(dataException.length > 0 && dataException[0].containsKey('Message'))
      {
        var exception = Methods.getString(dataException[0], 'Message');
        if(exception != "") throw Exception(exception);
      }
    }

    return retVal;
  }
}
